import React, { useContext } from 'react'
import { AppContext } from 'components/Contexts/AppContextProvider'
import {
  TimeStep,
  IPerformanceIndicator,
  ITimePeriod,
} from 'services/dataConsumptionContracts'
import { convertDateByTimeStep } from 'utils/utils'
import FluidConfigService from 'services/fluidConfigService'
import FluidPerformanceIndicator from 'components/ContentComponents/PerformanceIndicator/FluidPerformanceIndicator'
import KonnectorViewer from 'components/ContentComponents/KonnectorViewer/KonnectorViewer'

interface IndicatorContainerSwitcherProps {
  performanceIndicators: IPerformanceIndicator[]
  timeStep: TimeStep
  comparisonTimePeriod: ITimePeriod | null
}

const IndicatorContainerSwitcher: React.FC<IndicatorContainerSwitcherProps> = ({
  performanceIndicators,
  timeStep,
  comparisonTimePeriod,
}: IndicatorContainerSwitcherProps) => {
  const appContext = useContext(AppContext)
  const allConfiguredFluidTypes = appContext.fluidTypes
  const fluidConfig = new FluidConfigService().getFluidConfig()

  return (
    <div>
      {fluidConfig.map((fluid, index) => {
        return allConfiguredFluidTypes.includes(fluid.fluidTypeId) ? (
          <FluidPerformanceIndicator
            key={index}
            fluidType={fluid.fluidTypeId}
            performanceIndicator={performanceIndicators[fluid.fluidTypeId]}
            timePeriodText={convertDateByTimeStep(
              comparisonTimePeriod,
              timeStep
            )}
          />
        ) : null
      })}
      {fluidConfig.map((fluid, index) => {
        return allConfiguredFluidTypes.includes(fluid.fluidTypeId) ? null : (
          <KonnectorViewer key={index} fluidConfig={fluid} />
        )
      })}
    </div>
  )
}

export default IndicatorContainerSwitcher
